## Toothpaste attitudes

### Description

60 consumers were asked to respond to six questions to determine their attitudes towards toothpaste. In addition to the attitudinal responses we have information on the age and gender of the respondents.

### Variables

A data frame with 60 observations on 10 variables. The scores shown for variables v1-v6 indicate the level of agreement with the statement indicated on a 7-point scale where 1 = strongly disagree and 7 = strongly agree.

- id = Respondent id
- v1 = "It is important to buy a toothpaste that prevents cavities."
- v2 = "I like a toothpaste that gives shiny teeth."
- v3 = "A toothpaste should strengthen gums." 
- v4 = "I prefer a toothpaste that freshens breath."
- v5 = "Prevention of tooth decay is not an important benefit offered by a toothpaste."
- v6 = "An important consideration in buying a toothpaste is attractive teeth."
- age = Age of the respondent
- age.cat = A recoded version of the age variable. Respondents are classified in three categories: < 30, 30-39, and > 40
- gender = Gender of the respondent